@@ -1,26 +1,14 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kaddressbookconfigpluginlistwidget.h"
 #include "../plugininterface/kaddressbookplugininterface.h"
-#include <KAddressBookImportExport/KAddressBookImportExportPluginManager>
-#include <KAddressBookImportExport/KAddressBookImportExportPlugin>
+#include "../importexport/pluginmanager.h"
+#include "../importexport/plugin.h"
+
 #include "kaddressbook_configure_debug.h"
 #include <KLocalizedString>
 #include <PimCommon/GenericPlugin>
@@ -53,8 +41,8 @@ void KAddressBookConfigPluginListWidget::save()
                                                        KAddressBookPluginInterface::self()->configPrefixSettingKey(),
                                                        mPluginGenericItems);
 
-    PimCommon::ConfigurePluginsListWidget::savePlugins(KAddressBookImportExport::KAddressBookImportExportPluginManager::self()->configGroupName(),
-                                                       KAddressBookImportExport::KAddressBookImportExportPluginManager::self()->configPrefixSettingKey(),
+    PimCommon::ConfigurePluginsListWidget::savePlugins(KAddressBookImportExport::PluginManager::self()->configGroupName(),
+                                                       KAddressBookImportExport::PluginManager::self()->configPrefixSettingKey(),
                                                        mPluginImportExportItems);
 }
 
@@ -81,10 +69,10 @@ void KAddressBookConfigPluginListWidget::initialize()
                                                         mPluginGenericItems,
                                                         kaddressbookPluginToolsGroupName());
 
-    PimCommon::ConfigurePluginsListWidget::fillTopItems(KAddressBookImportExport::KAddressBookImportExportPluginManager::self()->pluginsDataList(),
+    PimCommon::ConfigurePluginsListWidget::fillTopItems(KAddressBookImportExport::PluginManager::self()->pluginsDataList(),
                                                         i18n("Import/Export Plugins"),
-                                                        KAddressBookImportExport::KAddressBookImportExportPluginManager::self()->configGroupName(),
-                                                        KAddressBookImportExport::KAddressBookImportExportPluginManager::self()->configPrefixSettingKey(),
+                                                        KAddressBookImportExport::PluginManager::self()->configGroupName(),
+                                                        KAddressBookImportExport::PluginManager::self()->configPrefixSettingKey(),
                                                         mPluginImportExportItems,
                                                         kaddressbookImportExportGroupName());
 
@@ -98,7 +86,7 @@ void KAddressBookConfigPluginListWidget::slotConfigureClicked(const QString &con
             PimCommon::GenericPlugin *plugin = KAddressBookPluginInterface::self()->pluginFromIdentifier(identifier);
             plugin->showConfigureDialog(this);
         } else if (configureGroupName == kaddressbookImportExportGroupName()) {
-            KAddressBookImportExport::KAddressBookImportExportPlugin *plugin = KAddressBookImportExport::KAddressBookImportExportPluginManager::self()->pluginFromIdentifier(identifier);
+            auto *plugin = KAddressBookImportExport::PluginManager::self()->pluginFromIdentifier(identifier);
             plugin->showConfigureDialog(this);
         } else {
             qCWarning(KADDRESSBOOK_CONFIGURE_LOG) << "Unknown configureGroupName" << configureGroupName;
